#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod
version:              1.6.2.1
visibility:           public
id:                   yesod-1.6.2.1-6euIpYDRh8Id7N2Ws9SDb
key:                  yesod-1.6.2.1-6euIpYDRh8Id7N2Ws9SDb
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>

category:             Web, Yesod
abi:                  3beb1c350491e7e90dde07b0291ad07b
exposed:              True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod
hs-libraries:         HSyesod-1.6.2.1-6euIpYDRh8Id7N2Ws9SDb
depends:
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-534uwm1BQ035a3x29nwuhR
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    fast-logger-3.2.4-1cpg8HEmFKJHREGz07DTCj
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    monad-logger-0.3.42-B7iIjYljCF17yNAjGa6SWC
    shakespeare-2.1.7.1-D8emm3abNY9A9458tjgb09
    streaming-commons-0.2.3.1-J3aACsbr7Bf4BJZCZqUImf
    template-haskell-2.20.0.0 text-2.0.2 unix-2.8.4.0
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3
    wai-3.2.4-56REQg4dhfjHKYLZyIkMb9
    wai-extra-3.1.18-5k2W4LqYhoDGzXjcRflwkf
    wai-logger-2.5.0-HobqtCrrapi2qdHWbvl44W
    warp-3.4.0-Bz53tmaUOCu1sZfrie2t5U
    yaml-0.11.11.2-FLCCKo0n0nJK5o0PhDW0y0
    yesod-core-1.6.28.0-Be95svBpeZ5LSUqspd0WFD
    yesod-form-1.7.9.2-Gbg2WJtgtuOEvQbpTkN9ef
    yesod-persistent-1.6.0.8-9kwHybTrZqOJjV7OCjmmZg

haddock-interfaces:   /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html:         /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

